#-----------------------------------------------------------------------------
# Project    : ELE8304 : Circuits intégrés à très grande échelle 
#-----------------------------------------------------------------------------
# File       : pwr.tcl
# Author     : Mickael Fiorentino <mickael.fiorentino@polymtl.ca>
# Lab        : grm@polymtl
# Created    : 2018-06-22
# Last update: 2019-03-29
#-----------------------------------------------------------------------------
# Description: Estimation du puissance du compteur BCD avec Voltus
# HOW-TO     : source setup.csh && cd implementation/pnr
#            : > voltus -files ${SCRIPTS_DIR}/pwr.tcl 
#-----------------------------------------------------------------------------

#----------------------------------------------------------------------------#
#                                 SETUP                                      #
#----------------------------------------------------------------------------#
set DESIGN compteur

set DO_INIT  1
set DO_STAT  0
set DO_DYN   1

set VCD_START "0"
set VCD_END   "39"

#----------------------------------------------------------------------------#
#                                   INIT                                     #
#----------------------------------------------------------------------------#
if { $DO_INIT } {
	
    read_design -cellview "$::env(PNR_OA_LIB) $DESIGN layout" -physical_data	

    set_pg_library_mode -extraction_tech_file $::env(BE_QRC_LIB)/gpdk045.tch -celltype techonly \
		                -default_area_cap 0.5 -power_pins {VDD 1.1} -ground_pins VSS            \
                        -decap_cells DECAP* -filler_cells FILL*                                 \
                        -current_distribution propagation 

	generate_pg_library -output $::env(PNR_REP_DIR)/power
}

#----------------------------------------------------------------------------#
#                                STATIC POWER                                #
#----------------------------------------------------------------------------#
if { $DO_STAT } {

    # Static mode
    set_power_analysis_mode -reset
    set_power_analysis_mode -method static               \
                            -analysis_view av_fast       \
                            -corner max                  \
                            -create_binary_db false      \
                            -write_static_currents false \
                            -honor_negative_energy true  \
                            -ignore_control_signals true

    # Activity
	set_default_switching_activity -reset
    set_default_switching_activity -input_activity 0.2 -period 1.0
	
    # Report Power
    report_power -format detailed -report_prefix ${DESIGN}.stat -output $::env(PNR_REP_DIR)/power
}

#----------------------------------------------------------------------------#
#                                 DYNAMIC POWER                              #
#----------------------------------------------------------------------------#
if { $DO_DYN } {

    # Reset mode
    set_power_analysis_mode -reset
    set_default_switching_activity -reset

    # Set dynamic mode
    set_power_analysis_mode -method dynamic_vectorbased                               \
                            -power_grid_library $::env(PNR_REP_DIR)/power/techonly.cl \
                            -analysis_view av_fast -corner max                        \
                            -report_stat true                                         \
                            -enable_rtl_vectorbased_dynamic_analysis true             \
                            -create_binary_db true                                    \
                            -disable_static false                                     \
                            -write_static_currents true                               \
                            -report_missing_flop_outputs false
	
    # Read VCD activity file
    read_activity_file -reset
    read_activity_file -format VCD $::env(SIM_PNR_DIR)/${DESIGN}.pnr.vcd \
                       -scope  ${DESIGN}_tb/dut -start $VCD_START -end $VCD_END

    # Report power
	report_power -format detailed -report_prefix ${DESIGN}.dyn -output $::env(PNR_REP_DIR)/power
}
